import { AbstractRepository } from '@crosslab/service-common';
import { ServiceConfigurationModel } from '../model.js';
export class ServiceConfigurationRepository extends AbstractRepository {
    dependencies = {};
    constructor() {
        super('ServiceConfiguration');
    }
    dependenciesMet() {
        return true;
    }
    isInitialized() {
        if (!this.dependencies.participant)
            return false;
        return true;
    }
    initialize(entityManager) {
        this.repository = entityManager.getRepository(ServiceConfigurationModel);
    }
    async write(model, data) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        if (data.serviceType)
            model.serviceType = data.serviceType;
        if (data.configuration)
            model.configuration = data.configuration;
        if (data.participants) {
            for (const participant of model.participants ?? []) {
                await this.dependencies.participant.remove(participant);
            }
            model.participants = [];
            for (const participant of data.participants) {
                const participantModel = await this.dependencies.participant.create(participant);
                model.participants.push(participantModel);
            }
        }
    }
    async format(model) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        const participantRepository = this.dependencies.participant;
        return {
            serviceType: model.serviceType,
            configuration: model.configuration ?? undefined,
            participants: await Promise.all(model.participants?.map(participant => participantRepository.format(participant)) ?? []),
        };
    }
    async remove(model) {
        if (!this.isInitialized())
            this.throwUninitializedRepositoryError();
        const participantRepository = this.dependencies.participant;
        if (model.participants) {
            await Promise.all([
                ...model.participants.map(participant => participantRepository.remove(participant)),
            ]);
        }
        await super.remove(model);
    }
    getDefaultFindOptionsRelations() {
        return {
            participants: true,
        };
    }
}
//# sourceMappingURL=serviceConfiguration.js.map