import { logger } from '@crosslab/service-common';
import { repositories } from '../../../database/dataSource.js';
import { InvalidStateError, MalformedExperimentError } from '../../../types/errors.js';
import { validateExperimentStatus } from '../../../types/typeguards.js';
import { createPeerconnections } from '../../peerconnection.js';
import { experimentUrlFromId } from '../../url.js';
async function checkDevices(experimentModel, clients, connectedMap) {
    await Promise.all(experimentModel.devices.map(async (device) => {
        const deviceUrl = device.instance?.url ?? device.resolvedDevice ?? device.url;
        const resolvedDevice = await clients.device.getDevice(deviceUrl);
        connectedMap.set(deviceUrl, !!resolvedDevice.connected); // TODO: better solution
    }));
    let allConnected = true;
    for (const value of connectedMap.values()) {
        allConnected &&= value;
    }
    return allConnected;
}
export async function createPeerconnectionsExperiment(experimentModel, clients) {
    const connectedMap = new Map();
    const connected = await checkDevices(experimentModel, clients, connectedMap);
    if (!connected)
        await new Promise((resolve, reject) => {
            let i = 0;
            const connectionInterval = setInterval(async () => {
                const allConnected = await checkDevices(experimentModel, clients, connectedMap);
                if (allConnected) {
                    resolve();
                    clearInterval(connectionInterval);
                }
                else if (i === 6) {
                    reject('Devices did not connect in time');
                }
                else {
                    i++;
                }
            }, 5000);
        });
    const experimentUrl = experimentUrlFromId(experimentModel.uuid);
    logger.log('info', 'Attempting to create peerconnections for experiment', {
        data: { experimentUrl },
    });
    if (experimentModel.status !== 'booking-updated')
        throw new InvalidStateError(`Expected experiment to have status 'booking-updated', instead has status '${experimentModel.status}'`);
    if (!validateExperimentStatus(experimentModel, 'booking-updated'))
        throw new MalformedExperimentError(`Experiment is in status 'booking-updated', but does not satisfy the requirements for this status`, 500);
    await createPeerconnections(experimentModel, clients);
    experimentModel.status = 'peerconnections-created';
    await repositories.experiment.save(experimentModel);
    logger.log('info', 'Successfully created peerconnections for experiment', {
        data: { experimentUrl },
    });
}
//# sourceMappingURL=peerconnectionCreation.js.map